@@ -6,13 +6,15 @@ use v5.14;
 
 use Moose::Role;
 
+use File::Spec;
 use File::stat;
-use IO::File::WithPath;
+use IO::File;
 use Plack::MIME;
+use Plack::Util;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 
 sub serve_static_file {
@@ -20,21 +22,24 @@ sub serve_static_file {
 
     my $res = $c->res;
 
-    unless ( -e $path ) {
-        Catalyst::Exception->throw( "File ${path} was not found" );
+    my $abs = File::Spec->rel2abs( "$path" );
+
+    unless ( -e $abs ) {
+        Catalyst::Exception->throw( "File ${abs} was not found" );
     }
 
-    my $fh = IO::File::WithPath->new( $path, "r" );
+    my $fh = IO::File->new( $abs, "r" );
     if ( defined $fh ) {
         binmode($fh);
+        Plack::Util::set_io_path( $fh, $abs );
         $res->body($fh);
 
-        $type //= Plack::MIME->mime_type($path);
+        $type //= Plack::MIME->mime_type($abs);
 
         my $headers = $res->headers;
         $headers->content_type("$type");
 
-        my $stat = stat($path);
+        my $stat = stat($abs);
         $headers->content_length( $stat->size );
         $headers->last_modified( $stat->mtime );
 
@@ -61,7 +66,7 @@ Catalyst::Plugin::Static::File - Serve a specific static file
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 SYNOPSIS
 
@@ -98,8 +103,11 @@ It uses L<Plack::MIME> to identify the content type, but you can override that.
 
 =item *
 
-It uses L<IO::File::WithPath>, which should play nicely with L<Plack::Middleware::XSendfile> and
-L<Plack::Middleware::ETag>.
+It adds a file path to the file handle, plays nicely with L<Plack::Middleware::XSendfile> and L<Plack::Middleware::ETag>.
+
+=item *
+
+It does not log anything.
 
 =back
 
